@@ -392,7 +392,10 @@ extern string Aac_ChannelLayout_GetString(const Aac_OutputChannel* const OutputC
     string Value;
     for (int i=0; i< OutputChannels_Size; i++)
     {
-        Value+=Aac_OutputChannelPosition[OutputChannels[i]];
+        if (OutputChannels[i]<Aac_OutputChannelPosition_Size)
+            Value+=Aac_OutputChannelPosition[OutputChannels[i]];
+        else
+            Value+=Ztring::ToZtring(OutputChannels[i]).To_UTF8();
         Value+=' ';
     }
     Value.resize(Value.size()-1);
@@ -416,6 +419,8 @@ extern string Aac_ChannelLayout_GetString(int8u ChannelLayout, bool IsMpegh3da=f
 }
 extern string Aac_ChannelLayout_GetString(const vector<Aac_OutputChannel>& OutputChannels)
 {
+    if (OutputChannels.empty())
+        return string();
     return Aac_ChannelLayout_GetString(&*OutputChannels.begin(), OutputChannels.size());
 }
 
@@ -525,6 +530,8 @@ extern string Aac_ChannelMode_GetString(int8u ChannelLayout, bool IsMpegh3da=fal
 }
 extern string Aac_ChannelMode_GetString(const vector<Aac_OutputChannel>& OutputChannels)
 {
+    if (OutputChannels.empty())
+        return string();
     return Aac_ChannelMode_GetString(&*OutputChannels.begin(), OutputChannels.size());
 }
 
