@@ -200,6 +200,12 @@ public :
           void      Inform_Replace_Set (const ZtringListList &NewInform_Replace);
           ZtringListList Inform_Replace_Get_All ();
 
+          void      Inform_Version_Set (bool NewValue);
+          bool      Inform_Version_Get ();
+
+          void      Inform_Timestamp_Set (bool NewValue);
+          bool      Inform_Timestamp_Get ();
+
           #if MEDIAINFO_ADVANCED
           Ztring    Cover_Data_Set (const Ztring &NewValue);
           Ztring    Cover_Data_Get ();
@@ -261,6 +267,10 @@ public :
           void      InitDataNotRepeated_GiveUp_Set (bool Value);
           bool      InitDataNotRepeated_GiveUp_Get ();
     #endif //MEDIAINFO_ADVANCED
+    #if MEDIAINFO_ADVANCED && defined(MEDIAINFO_FILE_YES)
+          void      TimeOut_Set (int64u Value);
+          int64u    TimeOut_Get ();
+    #endif //MEDIAINFO_ADVANCED && defined(MEDIAINFO_FILE_YES)
 
           void      MpegTs_MaximumOffset_Set (int64u Value);
           int64u    MpegTs_MaximumOffset_Get ();
@@ -289,6 +299,13 @@ public :
           bool        Format_Profile_Split_Get ();
     #endif //MEDIAINFO_ADVANCED
 
+    #if defined(MEDIAINFO_GRAPH_YES) && defined(MEDIAINFO_ADM_YES)
+        void        Graph_Adm_ShowTrackUIDs_Set(bool Value);
+        bool        Graph_Adm_ShowTrackUIDs_Get();
+        void        Graph_Adm_ShowChannelFormats_Set(bool Value);
+        bool        Graph_Adm_ShowChannelFormats_Get();
+    #endif //defined(MEDIAINFO_GRAPH_YES) && defined(MEDIAINFO_ADM_YES)
+
     #if defined(MEDIAINFO_EBUCORE_YES)
           void        AcquisitionDataOutputMode_Set (size_t Value);
           size_t      AcquisitionDataOutputMode_Get ();
@@ -322,6 +339,10 @@ public :
           inline void Log_Send(int8u Type, int8u Severity, int32u MessageCode, const char* Message) {}
     #endif //MEDIAINFO_EVENTS
 
+    #if defined(MEDIAINFO_GRAPHVIZ_YES)
+        bool GraphSvgPluginState();
+    #endif //defined(MEDIAINFO_GRAPH_YES)
+
     #if defined(MEDIAINFO_LIBCURL_YES)
           bool      CanHandleUrls();
           enum urlencode
@@ -370,6 +391,10 @@ private :
         int64u      InitDataNotRepeated_Occurences;
         bool        InitDataNotRepeated_GiveUp;
     #endif //MEDIAINFO_ADVANCED
+    #if MEDIAINFO_ADVANCED && defined(MEDIAINFO_FILE_YES)
+        int64u      TimeOut;
+    #endif //MEDIAINFO_ADVANCED && defined(MEDIAINFO_FILE_YES)
+
     int64u          MpegTs_MaximumOffset;
     int64u          MpegTs_MaximumScanDuration;
     bool            MpegTs_ForceStreamDisplay;
@@ -382,6 +407,10 @@ private :
     #if MEDIAINFO_ADVANCED
         bool        Format_Profile_Split;
     #endif //MEDIAINFO_ADVANCED
+    #if defined(MEDIAINFO_GRAPH_YES) && defined(MEDIAINFO_ADM_YES)
+        bool        Graph_Adm_ShowTrackUIDs;
+        bool        Graph_Adm_ShowChannelFormats;
+    #endif //defined(MEDIAINFO_GRAPH_YES) && defined(MEDIAINFO_ADM_YES)
     #if defined(MEDIAINFO_EBUCORE_YES) || defined(MEDIAINFO_NISO_YES) || MEDIAINFO_ADVANCED
         size_t      AcquisitionDataOutputMode;
         Ztring      ExternalMetadata;
@@ -409,6 +438,8 @@ private :
     std::map<Ztring, bool> Trace_Modificators; //If we want to add/remove some details
     bool            Language_Raw;
     bool            ReadByHuman;
+    bool            Inform_Version;
+    bool            Inform_Timestamp;
     bool            Legacy;
     bool            LegacyStreamDisplay;
     bool            SkipBinaryData;
