@@ -101,6 +101,7 @@ private :
     void moof_mfhd();
     void moof_traf();
     void moof_traf_sdtp();
+    void moof_traf_tfdt();
     void moof_traf_tfhd();
     void moof_traf_trun();
     void moov();
@@ -171,6 +172,10 @@ private :
     void moov_trak_mdia_minf_stbl_stps();
     void moov_trak_mdia_minf_stbl_stsc();
     void moov_trak_mdia_minf_stbl_stsd();
+    void moov_trak_mdia_minf_stbl_stsd_mebx();
+    void moov_trak_mdia_minf_stbl_stsd_mebx_keys();
+    void moov_trak_mdia_minf_stbl_stsd_mebx_keys_PHDR();
+    void moov_trak_mdia_minf_stbl_stsd_mebx_keys_PHDR_keyd();
     void moov_trak_mdia_minf_stbl_stsd_stpp();
     void moov_trak_mdia_minf_stbl_stsd_stpp_btrt() {moov_trak_mdia_minf_stbl_stsd_xxxx_btrt();}
     void moov_trak_mdia_minf_stbl_stsd_text();
@@ -260,6 +265,7 @@ private :
     void moov_trak_txas();
     void moov_trak_tref();
     void moov_trak_tref_chap();
+    void moov_trak_tref_cdsc();
     void moov_trak_tref_clcp();
     void moov_trak_tref_dpnd();
     void moov_trak_tref_fall();
@@ -275,6 +281,8 @@ private :
     void moov_trak_tref_tmcd();
     void moov_trak_tref_vdep();
     void moov_trak_udta();
+    void moov_trak_udta_free() { moov_udta_free(); }
+    void moov_trak_udta_Xtra() { moov_udta_Xtra(); }
     void moov_trak_udta_xxxx();
     void moov_udta();
     void moov_udta_AllF();
@@ -289,6 +297,7 @@ private :
     void moov_udta_DcMD_DcME_Mtmd();
     void moov_udta_DcMD_DcME_Rate();
     void moov_udta_FIEL();
+    void moov_udta_free() { free(); }
     void moov_udta_FXTC();
     void moov_udta_hinf();
     void moov_udta_hinv();
@@ -320,6 +329,7 @@ private :
     void moov_udta_tags_tseg_tshd();
     void moov_udta_WLOC();
     void moov_udta_XMP_();
+    void moov_udta_Xtra();
     void moov_udta_yrrc();
     void moov_udta_xxxx();
     void pdin();
@@ -335,6 +345,7 @@ private :
     void REDV();
     void REOB();
     void skip();
+    void sidx();
     void wide();
 
     //Helpers
@@ -376,6 +387,7 @@ private :
     int32u                                  Vendor;
     Ztring                                  Vendor_Version;
     Ztring                                  DisplayAspectRatio;
+    Ztring                                  FrameRate_Real;
     int64u                                  FirstMdatPos;
     int64u                                  LastMdatPos; //This is the position of the byte after the last byte of mdat
     int64u                                  FirstMoovPos;
@@ -459,6 +471,7 @@ private :
         int32u                  mvex_trex_default_sample_duration;
         int32u                  mvex_trex_default_sample_size;
         int32u                  TimeCode_TrackID;
+        int32u                  HasAtomStyle;
         bool                    TimeCode_IsVisual;
         bool                    IsPcm;
         bool                    IsPcmMono;
@@ -484,6 +497,8 @@ private :
         std::vector<int32u>     ForcedFor;
         std::vector<int32u>     Chapters;
         std::vector<int32u>     ChaptersFor;
+        std::vector<int32u>     Meta;
+        std::vector<int32u>     MetaFor;
         float32                 CleanAperture_Width;
         float32                 CleanAperture_Height;
         float32                 CleanAperture_PixelAspectRatio;
@@ -538,6 +553,7 @@ private :
             mvex_trex_default_sample_duration=0;
             mvex_trex_default_sample_size=0;
             TimeCode_TrackID=(int32u)-1;
+            HasAtomStyle=0;
             TimeCode_IsVisual=false;
             IsPcm=false;
             IsPcmMono=false;
