@@ -21,7 +21,6 @@
 #if defined(MEDIAINFO_ANCILLARY_YES)
     #include <MediaInfo/Multiple/File_Ancillary.h>
 #endif //defined(MEDIAINFO_ANCILLARY_YES)
-#include <MediaInfo/Video/File_DolbyVisionMetadata.h>
 #include "MediaInfo/MediaInfo_Internal.h"
 #include "MediaInfo/TimeCode.h"
 #include <vector>
@@ -32,6 +31,10 @@
 namespace MediaInfoLib
 {
 
+class File_DolbyVisionMetadata;
+class File_Adm;
+class File_DolbyAudioMetadata;
+
 //***************************************************************************
 // Class File_Mxf
 //***************************************************************************
@@ -183,6 +186,8 @@ protected :
     void SoundfieldGroupLabelSubDescriptor();
     void GroupOfSoundfieldGroupsLabelSubDescriptor();
     void AVCSubDescriptor();
+    void IABEssenceDescriptor();
+    void IABSoundfieldLabelSubDescriptor();
     void OpenIncompleteHeaderPartition();
     void ClosedIncompleteHeaderPartition();
     void OpenCompleteHeaderPartition();
@@ -207,7 +212,10 @@ protected :
     void SDTI_ControlMetadataSet();
     void SystemScheme1();
     void DMScheme1();
+    void Application04_01_04_01_01();
+    void Application04_01_04_02_01();
     void Application05_09_01();
+    void Application_08_BodySID();
     void AS11_AAF_Core();
     void AS11_AAF_Segmentation();
     void AS11_AAF_UKDPP();
@@ -1166,6 +1174,7 @@ protected :
     void           ChooseParser_Jpeg2000(const essences::iterator &Essence, const descriptors::iterator &Descriptor);
     void           ChooseParser_ProRes(const essences::iterator &Essence, const descriptors::iterator &Descriptor);
     void           ChooseParser_DolbyVisionFrameData(const essences::iterator& Essence, const descriptors::iterator& Descriptor);
+    void           ChooseParser_Iab(const essences::iterator& Essence, const descriptors::iterator& Descriptor);
 
     //Helpers
     int32u Vector(int32u ExpectedLength=(int32u)-1);
@@ -1323,8 +1332,12 @@ protected :
 
     // Extra metadata
     int64u ExtraMetadata_Offset;
-    int32u ExtraMetadata_SID;
+    set<int32u> ExtraMetadata_SID;
     File_DolbyVisionMetadata* DolbyVisionMetadata;
+    File_DolbyAudioMetadata* DolbyAudioMetadata;
+    #if defined(MEDIAINFO_ADM_YES)
+    File_Adm* Adm;
+    #endif
 
     //Demux
     #if MEDIAINFO_DEMUX
